# QFAST-SC: SearchCompiler Plugin for QFAST

QFAST-SC packages the SearchCompiler as a native tool plugin for [QFAST](https://github.com/edyounis/qfast). This package imports the SearchCompiler which can be found [here](https://github.com/WolfLink/search_compiler) and its license [here](https://https://github.com/WolfLink/search_compiler/blob/master/LICENSE).

## Installation

The best way to install this python package is with pip.

```
pip install qfast-sc
```

## Copyright

Quantum Fast Approximate Synthesis Tool (QFAST) Copyright (c) 2020,
The Regents of the University of California, through Lawrence Berkeley
National Laboratory (subject to receipt of any required approvals from
the U.S. Dept. of Energy). All rights reserved.

If you have questions about your rights to use or distribute this software,
please contact Berkeley Lab's Intellectual Property Office at IPO@lbl.gov.

NOTICE.  This Software was developed under funding from the U.S. Department
of Energy and the U.S. Government consequently retains certain rights.  As
such, the U.S. Government has been granted for itself and others acting on
its behalf a paid-up, nonexclusive, irrevocable, worldwide license in the
Software to reproduce, distribute copies to the public, prepare derivative
works, and perform publicly and display publicly, and to permit others to do so.

